function clist = etsi_cablesSDSL(clist);
%% ===========================================================================
%etsi_cablesSDSL(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist = etsi_cablesSDSL(ex.clist);             Add to existing clist
%   cableparam = getList(ex.clist,'ETSI-SDSL-PVC04'); Get a PVC 0.4 SDSL cable
%
%   ex.clist = etsi_cablesSDSL([]);                   Create a new clist
%   cableparam = getList(ex.clist,'ETSI-SDSL-PE04');  Get a PE 0.4 SDSL cable
%
% Reference:
%   ETSI STC TM6 PD 980p10a5 "Laboratory Performance tests for xDSL
%   systems" (feb 5, 2001)
%   Draft ITU-T Recommendation G.996.1 "Test procedures for DSL tranceivers"
%   ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot Schmid (Gernot.Schmid@arcs.ac.at)
%
% CVS:       $Id: etsi_cablesSDSL.m,v 3.1 2002/12/27 15:48:08 tono Exp $
%% ===========================================================================
% Change History
%      2000-03-14 (ToNo) Moved cable defs. into xdsldefs and did the list thing
%      2000-03-16 (GS)   Added ETSI SDSL Test cables:
%                        PE04 PE05 PE06 PE08 PVC032 PVC04 PVC063
%      2000-06-07 (GS)   SDSL Test cable extensions beyond 500 kHz
%                        According to ETSI Helsinki 2000 TD18 
%      2002-03-18 (ToNo) Renamed the SDSL cables
%      2002-08-23 (ToNo) Split up according to technology
%% ===========================================================================

%%============================================================================
% ETSI - SDSL/HDSL Testcables only defined up to 2 MHz
% From  ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03

cable=[];
cable.name='ETSI-SDSL-PE04';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz
cable.param.Rtmpl=1e-3.*[268 268 269 271 282 295 312 390 425 493 582 816];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[680 678 675 669 650 642 635 619 608 593 582 571];       % in H/m
cable.param.Ctmpl=1e-12.*[45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5];%in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PE05';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[172 172 173 175 190 207 227 302 334 392 466 655];       % in Ohm/m
cable.param.Ltmpl= 1e-9.*[680 678 675 667 646 637 629 603 592 577 572 565];      % in H/m
cable.param.Ctmpl= 1e-12.*[25 25 25 25 25 25 25 25 25 25 25 25];              % in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PE06';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[119 120 121 125 146 167 189 260 288 340 405 571];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[700 695 693 680 655 641 633 601 590 576 570 560];       % in H/m  
cable.param.Ctmpl=1e-12.*[56 56 56 56 56 56 56 56 56 56 56 56];               % in F/m  
clist=insertList(clist,cable);
    
cable=[];
cable.name='ETSI-SDSL-PE08';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz  
cable.param.Rtmpl=1e-3.*[67 70 72.5 75.0 91.7 105 117 159 177.5 209 250 353];    % in Ohm/m
cable.param.Ltmpl=1e-9.*[700 700 687 655 628 609 595 568 560 553 547 540];       % in H/m  
cable.param.Ctmpl=1e-12.*[37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8];%in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PVC032';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6]; % in Hz
cable.param.Rtmpl= 1e-3.*[419 419 419 419 427 453 493 679 750 877 1041 1463];     % in Ohm/m 
cable.param.Ltmpl= 1e-9.*[650 650 650 650 647 635 621 577 560 546 545 540];     % in H/m 
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];    % in F/m 
clist=insertList(clist,cable);
 
cable=[];
cable.name='ETSI-SDSL-PVC04';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz  
cable.param.Rtmpl=1e-3.*[268 268 268 268 281 295 311 391 426 494 584 817];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[650 650 650 650 635 627 619 592 579 566 559 550];       % in H/m  
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];     % in F/m 
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PVC063';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[108 108 108 111 141 173 207 319 361 427 510 720];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[635 635 635 630 604 584 560 492 469 450 442 434];       % in H/m  
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];     % in F/m 
clist=insertList(clist,cable);
